const questions = [
    {
        "grouping": "Allgemein",
        "short": "Notwendig?",
        "question": "Ist das Zeigen der personenbezogenen Bilder für Ihre wissenschaftliche Argumentation notwendig?",
        "answers": [
            "Ja",
            "Nein"
        ],
        "score": [
            0,
            2
        ],
        "info": "Als \"personenbezogene Bilder\" verstehen wir Bilder, die Personen identifizierbar machen oder persönliche Informationen preisgeben. Solches Bildmaterial stammt in der Regel aus zwei Hauptquellen: Bereits existierende („gefundene“) Bilder aus privaten, institutionellen und öffentlichen Quellen oder Bilder, die im Zuge der Datenerhebung eigens erstellt oder von den Befragten auf Initiative der Forschenden präsentiert wurden (<a href=\"https://methods.sagepub.com/book/the-sage-handbook-of-visual-research-methods-2e\">Pauwels, 2020</a>, S. 16-18).",
        "yesRecommendation": "Wir empfehlen, noch einmal für jedes gezeigte Bild kritisch zu prüfen, ob es tatsächlich für die wissenschaftliche Argumentation notwendig ist. Erwägen Sie anschließend Maßnahmen zur Anonymisierung der personenbezogenen Bilder: Sofern Ihre Argumentation beispielsweise keine Aussagen zu Mimik und Gestik enthält, besteht in der Regel kein Grund, Gesichter unverändert zu zeigen.",
        "noRecommendation": "Wenn (personenbezogene) Bilder nicht zwingend für Ihre wissenschaftliche Argumentation erforderlich sind und stattdessen eher dekorativen Zwecken dienen, sollte aus forschungsethischen Gründen auf die Bildverwendung verzichtet werden. Zudem könnte bei rein dekorativen Verwendungszwecken das Zeigen auch rechtlich problematisch sein. Wir empfehlen, die Bilder nicht zu zeigen."
    },
    {
        "grouping": "Allgemein",
        "short": "Informed Consent?",
        "question": "Liegt eine informierte Einwilligung der abgebildeten Personen vor? (englisch: informed consent; kurz: IC)",
        "answers": [
            "Ja",
            "Nein"
        ],
        "score": [
            0,
            2
        ],
        "info": "Beim Zeigen von Bildern in allen Kontexten der Wissenschaftskommunikation gilt: Informierte Einwilligung ist ein zentraler forschungsethischer Grundsatz, der für personenbezogenes Bildmaterial besonders wichtig ist (siehe z. B. <a href=\"https://www.halem-verlag.de/produkt/vernetzte-bilder\">Venema et al., 2020</a>, S. 292; <a href=\"https://link.springer.com/referencework/10.1007/978-3-658-06738-0\">Lobinger et al., 2019</a>, S. 739-740). In einer informierten Einwilligung sollten Teilnehmende oder gezeigte Personen \"aufgeklärt werden über den Zweck der Studie, ihre Inhalte und das konkrete Vorgehen, damit sie auf dieser Basis entscheiden können, ob sie teilnehmen wollen oder nicht\" (<a href=\"https://doi.org/10.1007/978-3-658-36629-2_8-1\">Schlütz & Zillich, 2023</a>, S. 7).",
        "yesRecommendation": "Die informierte Einwilligung liegt vor. Bevor die personenbezogenen Bilder gezeigt werden, vergewissern Sie sich, dass der beabsichtigte Publikationskontext durch die informierte Einwilligung abgedeckt ist. Im Zweifelsfall sollten Sie zusätzliche Klarheit durch eine erneute Rückfrage schaffen. Die informierte Einwilligung sollte auch Informationen dazu beinhalten, wie die Bilder gezeigt werden sollten (z.B. anonymisiert oder nicht anonymisiert). Wenn eine Anonymisierung erfolgt, stellen Sie sicher, dass die gewählte Form der Anonymisierung dem Wunsch der gezeigten Personen entspricht. Bedenken Sie dabei, dass sich ein Anonymisierungswunsch kontextabhängig, aber auch von Person zu Person individuell unterscheiden kann. Hier spielt der Balanceakt zwischen dem Schutz der Personen und ihrer Anerkennung eine Rolle bei der forschungsethischen Entscheidungsfindung (siehe z. B. <a href=\"https://www.halem-verlag.de/produkt/vernetzte-bilder\">Venema et al., 2020</a>). Zuletzt gilt: Auch wenn die Person ihr Einverständnis zur nicht anonymisierten Veröffentlichung gegeben hat, ist es die Aufgabe des Forschenden, sich zu vergewissern, ob eventuell doch eine Anonymisierung erforderlich ist. ",
        "noRecommendation": "Die informierte Einwilligung liegt nicht vor. Wägen Sie ab, ob Sie das Zeigen der Bilder für Ihre wissenschaftliche Argumentation erforderlich ist. Falls ja, holen Sie wenn möglich die informierte Einwilligung der gezeigten Personen ein. Falls dies nicht möglich ist, denken Sie darüber nach, ob das Zeigen der Bilder von öffentlichem Interesse ist. Überlegen Sie, welche Personengruppe gezeigt wird. Dies kann einen Unterschied machen (z.B. bei Personen des öffentlichen Interesses). Auch eine Schaden-Nutzen-Abwägung ist wichtig: Welcher potenzielle Schaden kann den gezeigten Personen durch das Zeigen der Bilder im Rahmen Ihrer wissenschaftlichen Arbeit entstehen (siehe z. B. <a href=\"https://doi.org/10.1007/978-3-658-36629-2_8-\">Schlütz & Zillich, 2023</a>)? Falls Sie entscheiden, die Veröffentlichung der Bilder zu vermeiden oder sie vollständig zu anonymisieren (beispielsweise durch Reenactment oder Verfremdung mittels Software-Tools), bedenken Sie, dass dies unter Umständen zum sogenannten \"Silencing\" führen kann: Das Nicht-Zeigen oder Anonymisieren der Bilder kann bedeuten, die Stimmen der Personen ungehört zu lassen, obwohl diese möglicherweise gerne sichtbar wären. Hierbei sollte eine ausgewogene Abwägung zwischen dem Schutz der Personen und deren Anerkennung in der forschungsethischen Entscheidungsfindung berücksichtigt werden (vgl. <a href=\"https://www.halem-verlag.de/produkt/vernetzte-bilder\">Venema et al., 2020</a>)."
    },
    {
        "grouping": "Allgemein",
        "short": "Auffindbarkeit der Bilder?",
        "question": "Handelt es sich um personenbezogene Bilder, die im Internet verfügbar sind?",
        "answers": [
            "Ja",
            "Nein"
        ],
        "score": [
            1,
            0
        ],
        "info": "Die Kommunikations- und Medienwissenschaft erforscht oftmals Online-Inhalte. Dies umfasst auch personenbezogene visuelle Elemente, die online verfügbar sind. Für diese Bildarten gelten einige besondere Anforderungen, da die Bilder oftmals auffindbar sind und so eine De-Anonymisierung der Personen erfolgen könnnte. ",
        "yesRecommendation": "Die Bilder sind im Internet verfügbar. Bei vermeintlich anonymisierten personenbezogenen Bilder, die im Internet verfügbar sind, ist es wichtig, deren Rückverfolgbarkeit zu erschweren. Trotz einer vermeintlichen Anonymisierung durch Verpixelung oder Verfremdung besteht die Möglichkeit, dass verschiedene Algorithmen und Technologien (beispielsweise Reverse Image Search Engines) visuelle Merkmale wie Farben, Formen, Texturen und Muster erkennen. Diese Erkennung kann dazu führen, dass das Bild sowie beispielsweise das zugehörige Social Media Profil identifizierbar werden, wodurch die Anonymität der abgebildeten Personen aufgehoben wird. ",
        "noRecommendation": "Beim Zeigen personenbezogener Bilder, die nicht im Internet verfügbar sind, gibt es weniger ethische Bedenken hinsichtlich der technischen Rückverfolgbarkeit der Bilder via Rückwärtssuchmaschinen. Bedenken Sie dennoch, dass diese gegebenenfalls in Zukunft im Internet verfügbar sein könnten. Trotz einer vermeintlichen Anonymisierung durch Verpixelung oder Verfremdung besteht die Möglichkeit, dass verschiedene Algorithmen und Technologien (beispielsweise Reverse Image Search Engines) visuelle Merkmale wie Farben, Formen, Texturen und Muster erkennen. Diese Erkennung kann dazu führen, dass das Bild sowie beispielsweise das zugehörige Social Media Profil identifizierbar werden, wodurch die Anonymität der abgebildeten Personen aufgehoben wird. "
    },
    {
        "grouping": "Allgemein",
        "short": "Traumatisierende Bilder?",
        "question": "Sind die personenbezogenen Bilder potenziell (re-)traumatisierend oder handelt es sich um sensible Themenbereiche?",
        "answers": [
            "Ja",
            "Nein"
        ],
        "score": [
            2,
            1
        ],
        "info": "Beispielsweise potenziell (re-)traumatisierende Bilder von Kriegen, Krisen, Amoktaten oder sensible Themenbereichen wie beispielsweise Gesundheit, Religion, politische Ansichten, Sexualität.",
        "yesRecommendation": "Es handelt sich um potenziell (re-)traumatisierende Bilder oder einen sensiblen Themenbereich. Vermeiden Sie daher die Veröffentlichung der personenbezogenen Bilder, da das Zeigen mögliche Auswirkungen sowohl auf die gezeigten Personen als auch auf die Betrachtenden haben kann. Dies umfasst (Re-)Traumatisierung, emotionale Belastung wie Trauer, Angst und Wut, aber auch bespielsweise die Desensibilisierung gegenüber Gewalt. Bedenken Sie auch den Opferschutz. Wenn sich das Zeigen der Bilder nicht vermeiden lässt und für die wissenschaftliche Aussage und Transparenz essenziell ist, ist eine besonders sorgfältige Schaden-Nutzen-Abwägung erforderlich. Bedenken Sie darüber hinaus: Auch wenn eine informierte Einwilligung vorliegt, stellt sich die Frage, ob die abgebildeten Personen tatsächlich über ausreichende Informationen (z.B. zu Wissenschaftskontexten) verfügen und verstehen können, wozu sie ihre Zustimmung geben und welche potenziellen Implikationen und Risiken mit der Erlaubnis zur Aufnahme und Nutzung von Bildern durch die Forschenden verbunden sind (u. a. <a href=\"https://doi.org/10.4135/978085702502\">Pink 2007</a>). Verwenden Sie in jedem Fall eine Trigger-Warnung, wenn Sie die Bilder zeigen. Wenn ein Zeigen der Bilder nötig ist, überlegen Sie auch, ob eventuell auch andere, nicht personenbezogene Bildvarianten vorliegen und genutzt werden können. ",
        "noRecommendation": "Es handelt sich scheinbar nicht um potenziell (re-)traumatisierende Bilder oder einen sensiblen Themenbereich. Bitte beachten Sie jedoch, dass Menschen unterschiedlich auf Bilder reagieren können. Was für manche unproblematisch erscheint, kann auf andere Menschen emotional belastend oder sogar (re-)traumatisierend wirken. Auch wenn Sie als Forschende keine belastende Wirkung erwarten, ist es wichtig zu bedenken, dass die individuelle Wahrnehmung stark variieren kann. Bitte berücksichtigen Sie dies bei Ihrer ethisch verantwortungsvollen Entscheidungsfindung. Wenn Sie zum Ergebnis kommen, dass es sich tatsächlich nicht um potenziell (re-)traumatisierende Bilder oder einen sensiblen Themenbereich handelt, sind keine zusätzlichen forschungsethischen Abwägung im Vergleich zu anderen personenbezogenen Bilder erforderlich. "
    },
    {
        "grouping": "Abgebildete Personen",
        "short": "Schutzwürdige Gruppen?",
        "question": "Zählen die abgebildeten Personen zu besonders vulnerable Personen oder Gruppen?",
        "answers": [
            "Ja",
            "Nein"
        ],
        "score": [
            2,
            0
        ],
        "info": "Als besonders vulnerabel verstehen wir Personen oder Gruppen, die aufgrund spezifischer Merkmale in verschiedenen Kontexten erhöhten Risiken ausgesetzt sind und deren gesellschaftliche Teilhabe sowie grundlegende Rechte und Freiheiten beeinträchtigt werden können. Zu diesen Personengruppen zählen unter anderem Kinder und Jugendliche, Menschen mit Behinderungen, Menschen mit Fluchthintergrund und Migrant:innen sowie ethnische, politische und religiöse Minderheiten. Je nach Kontexten können unterschiedliche Personen oder Gruppen als vulnerabel gelten. ",
        "yesRecommendation": "Schätzen Sie unbedingt die physischen und psychischen Risiken und Schäden ab, die durch ihre Veröffentlichung der Bilder entstehen könnten (Schaden-Nutzen-Abwägung, siehe z. B. <a href=\"https://doi.org/10.1007/978-3-658-36629-2_8-\">Schlütz & Zillich, 2023</a>). Denken Sie darüber nach, ob sie die Veröffentlichung der Bilder vermeiden oder die Bilder anonymisieren können (z. B. durch Reenactment, Verfremdung durch Software-Tools). Bedenken Sie bei Ihrer Abwägung auch, dass der Verzicht auf die Veröffentlichung der Bilder oder die vollständige Anonymisierung unter Umständigen zum sogenannten \"Silencing\" führen könnte: Bilder nicht zu zeigen oder sie zu anonymisieren kann bedeuten, die Stimmen der Personen “zum Schweigen” zu bringen, obwohl die Personen gerne sichtbar wären. Hier sollte entsprechend der Balanceakt zwischen dem Schutz der Personen und ihrer Anerkennung eine Rolle bei der forschungsethischen Entscheidungsfindung spielen (siehe z. B. <a href=\"https://www.halem-verlag.de/produkt/vernetzte-bilder\">Venema et al., 2020</a>).",
        "noRecommendation": "Es gibt keine zusätzlichen ethischen Bedenken bezüglich besonders vulnerabler Personengruppen. Folglich sind keine zusätzlichen forschungsethischen Abwägung im Vergleich zu anderen personenbezogenen Bilder erforderlich. "
    },
    {
        "grouping": "Abgebildete Personen",
        "short": "Öffentliche Person?",
        "question": "Handelt es sich bei den abgebildeten Personen um Personen des öffentlichen Lebens?",
        "answers": [
            "Ja",
            "Nein"
        ],
        "score": [
            0,
            1
        ],
        "info": "Als Personen des öffentlichen Lebens verstehen wir Personen, deren Bekanntheitsgrad und öffentliche Präsenz sie in eine Position rücken, in der sie eine gewisse Kontrolle über ihre Privatsphäre zugunsten öffentlicher Interessen aufgeben. Häufig sind Personen des öffentlichen Lebens Tätigkeiten in Politik, Unterhaltung, Sport oder anderen Bereichen tätig und erfahren dort eine erhöhte Aufmerksamkeit. (siehe <a href=\"https://media-kanzlei.com/rechtsthemen/person-des-oeffentlichen-lebens/\">Riemenschneider o. D.</a>)",
        "yesRecommendation": "Die abgebildeten Personen sind Personen des öffentlichen Lebens, was die ethischen Bedenken hinsichtlich des Zeigens der personenbezogenen Bilder reduziert. Dennoch ist es wichtig, auch weitere Aspekte zu beachten wie beispielsweise die Wahrung der Privatsphäre, die Einhaltung der Persönlichkeitsrechte und der Respekt vor der Würde der abgebildeten Personen. Auch sollten Sie darauf achten, dass die Bilder nicht manipulativ oder irreführend verwendet werden und keine negativen Konsequenzen für die abgebildeten Personen haben.",
        "noRecommendation": "Erhöhte Vorsicht ist geboten, da die Personen nicht im öffentlichen Interesse stehen. Verwenden Sie zusätzliche Anonymisierung, falls dies nicht im Widerspruch zu den Wünschen der Personen selbst steht. Der informierten Einwilligung kommt hier eine besonders wichtige Rolle zu. "
    },
    {
        "grouping": "Abgebildete Personen",
        "short": "Silencing?",
        "question": "Könnte das Nicht-Zeigen oder die Anonymisierung der personenbezogenen Bilder dazu führen, dass marginalisierte Gruppen unsichtbar(er) werden? (Silencing)",
        "answers": [
            "Ja",
            "Nein"
        ],
        "score": [
            1,
            0
        ],
        "info": "Als \"marginalisiert\" verstehen wir Personengruppen, die aufgrund von Faktoren, auf die sie in der Regel keinen Einfluss haben, nicht die gleichen Chancen haben wie andere Gruppen in einer Gesellschaft (siehe <a href=\"https://www.who.int/publications/m/item/glossary-of-terms-used-for-health-impact-assessment-hi\">WHO, 2010</a>). Meist ist Marginalisierung auch mit einer reduzierten Sichtbarkeit verbunden. ",
        "yesRecommendation": "Generell ist zu beachten, dass das Nicht-Zeigen der Bilder oder deren Anonymisierung bedeuten kann, die Stimmen der Personen \"zum Schweigen” zu bringen, obwohl die Personen gerne sichtbar wären. Dies könnte dazu führen, dass die Anliegen und Perspektiven dieser Menschen noch repräsentatiert werden. Es ist wichtig, eine Balance zwischen dem Schutz der Personen und ihrer Anerkennung zu finden (siehe z. B. <a href=\"https://www.halem-verlag.de/produkt/vernetzte-bilder\">Venema et al., 2020</a>). Wenn Ihnen eine informierte Einwilligung vorliegt, vergewissern Sie sich, dass der beabsichtigte Publikationskontext durch die informierte Einwilligung abgedeckt ist. Im Zweifelsfall sollten Sie zusätzliche Klarheit durch eine erneute Rückfrage schaffen. Wenn eine Anonymisierung erfolgt, stellen Sie sicher, dass die gewählte Form der Anonymisierung dem Wunsch der gezeigten Personen entspricht. Bedenken Sie dabei, dass sich ein Anonymisierungswunsch kontextabhängig, aber auch von Person zu Person individuell unterscheiden kann.",
        "noRecommendation": "Es gibt keine zusätzlichen ethischen Bedenken."
    },
    {
        "grouping": "Abgebildete Personen",
        "short": "Amplification?",
        "question": "Würde das Zeigen der personenbezogenen Bilder „kontroversen“ Gruppen mehr Aufmerksamkeit verschaffen? (Amplification)",
        "answers": [
            "Ja",
            "Nein"
        ],
        "score": [
            1,
            0
        ],
        "info": "Als \"kontroverse\" Gruppen verstehen wir soziale, politische oder ideologische Gruppen, deren Ansichten oder Handlungen polarisieren und Konflikte in der Gesellschaft auslösen. Diese Gruppen weichen in der Regel von gesellschaftlich legitimierten Normen ab.",
        "yesRecommendation": "Es ist ratsam, auf eine Veröffentlichung zu verzichten, um zu verhindern, dass kontroversen Gruppen zusätzliche Aufmerksamkeit zukommt. Falls sich die Veröffentlichung nicht vermeiden lässt und für die wissenschaftliche Aussage und Transparenz essenziell ist, sollten Sie eine Trigger-Warnung hinzufügen, um Personen auf die Bilder vorzubereiten und diejenigen zu schützen, die stark darauf reagieren könnten. Konsultieren Sie unbedingt den Forschungsstand zu Ihrem Thema. Beispielsweise liegen Erkenntnisse vor, die besagen, dass das Zeigen von Täter:innen (etwa im Kontext von Terroranschlängen) deren Aufmersamkeitsstragien folgt und gegebenfalls Nachahmer:innen anspricht. Wägen Sie daher besonders gut ab, ob ein Zeigen gerechtfertigt ist.  ",
        "noRecommendation": "Es gibt keine zusätzlichen ethischen Bedenken."
    },
    {
        "grouping": "Publikationskontexte",
        "short": "Intern?",
        "question": "Möchten Sie die personenbezogenen Bilder wissenschaftsintern zeigen (z.B. in Präsentationen, in Workshops, in der Lehre)?",
        "answers": [
            "Ja",
            "Nein"
        ],
        "score": [
            1,
            0
        ],
        "info": "Im Wissenschaftskontext gibt es vielfältige Formen der Publikation und des Sichtbarmachens. Diese haben einen Einfluss auf forschungsethische Überlegungen beim Zeigen von personenbezogenen Bildern. ",
        "yesRecommendation": "Verwenden Sie die Bilder nur, wenn alle ethischen Aspekte berücksichtigt wurden. Erklären Sie bei Präsentationen ggf., dass es sich um sensible Daten handelt und fordern Sie das Publikum – etwa einer Konferenzpräsentation oder eines Workshop – auf, keine Fotos zu machen. Dies erfolgt bestenfalls durch eine Disclaimer-Folie zu Beginn der Präsentation und zusätzlicher mündlicher Erklärung. Machen Sie den Zuhörenden deutlich, dass Sie selbst die Einwilligung haben, die Bilder zu zeigen, aber das Publikum nicht die Einwilligung, Fotos anzufertigen und diese zu verbreiten. Falls die informiertie Einwilligung nicht vorliegt, holen Sie diese wenn möglich ein. Falls dies nicht möglich ist, ist sehr gut abzuwägen, ob Sie die Bilder zeigen. Hier braucht es eine nachvollziehbare Argumentation (z. B. nur Personen des öffentlichen Lebens). Gehen Sie auch mit internen Präsentationen vorsichtig um, da Inhalte oft in Forschungsteams zirkulieren und eine angemessene Speicherung und Sicherung der personenbezogenen Inhalte erschwert wird. Dies gilt gleichermaßen für die Vernwedung in der Lehre. Stellen Sie sicher, dass Sie die informierte Einwilligung für die Verwendung in der Lehre eingeholt haben. Und bedenken Sie, dass Lehrinhalte von besonders großen und heterogenen Publikat genutzt und gegebenfalls geteilt werden können. Denken Sie bei allen Präsentationen auch an potenziellen Verbreitungen der Präsentationsfolien nach dem Vortrag. Wenn Sie die Folien anderen Forschenden bereitstellen möchten, achten Sie unbedingt auf eine angemessenen Nachbearbeitung. Dies kann bedeuten, Bilder bzw. Folien zu löschen bzw. zu anonymisieren. In diesem Zusammenhang sind auch Reverse Image Search Engines von Bedeutung, insbesondere wenn die zu zeigenden Bilder im Internet verfügbar sind. Trotz einer vermeintlichen Anonymisierung durch Verpixelung oder Verfremdung besteht die Möglichkeit, dass verschiedene Algorithmen und Technologien visuelle Merkmale wie Farben, Formen, Texturen und Muster erkennen.",
        "noRecommendation": "Es gibt keine zusätzlichen ethischen Bedenken."
    },
    {
        "grouping": "Publikationskontexte",
        "short": "Publikation?",
        "question": "Möchten Sie die personenbezogenen Bilder im Rahmen einer wissenschaftlichen Publikation zeigen? (z. B. Sammelbandbeitrag)",
        "answers": [
            "Ja",
            "Nein"
        ],
        "score": [
            1,
            0
        ],
        "info": "Im Wissenschaftskontext gibt es vielfältige Formen der Publikation und des Sichtbarmachens. Diese haben einen Einfluss auf forschungsethische Überlegungen beim Zeigen von personenbezogenen Bildern.",
        "yesRecommendation": "Stellen Sie vor dem Zeigen der Bilder sicher, dass der Kontext, in dem Sie die Bilder zeigen möchten, von der informierten Einwilligung abgedeckt ist. Verwenden Sie die Bilder nur, wenn alle ethischen Aspekte berücksichtigt wurden. In diesem Zusammenhang sind auch Reverse Image Search Engines von Bedeutung, insbesondere wenn die zu zeigenden Bilder im Internet verfügbar sind. Trotz einer vermeintlichen Anonymisierung durch Verpixelung oder Verfremdung besteht die Möglichkeit, dass verschiedene Algorithmen und Technologien visuelle Merkmale wie Farben, Formen, Texturen und Muster erkennen. ",
        "noRecommendation": "Es gibt keine zusätzlichen ethischen Bedenken."
    },
    {
        "grouping": "Publikationskontexte",
        "short": "Extern?",
        "question": "Möchten Sie die personenbezogenen Bilder im Rahmen externer Wissenschaftskommunikation zeigen? (z. B. journalistische Berichterstattung, institutionelle Wissenschaftskommunikation, eigene Wissenschaftskommunikation)",
        "answers": [
            "Ja",
            "Nein"
        ],
        "score": [
            2,
            0
        ],
        "info": "Im Wissenschaftskontext gibt es vielfältige Formen der Publikation und des Sichtbarmachens. Diese haben einen Einfluss auf forschungsethische Überlegungen beim Zeigen von personenbezogenen Bildern.",
        "yesRecommendation": "Stellen Sie vor dem Zeigen der Bilder sicher, dass der Kontext, in dem Sie die Bilder zeigen möchten, von der informierten Einwilligung abgedeckt ist. Setze Sie bei der Verbreitung an größere Publika und außerhalb \"klassischer\" wissenschaftsinterner Veröffentlichungspraktiken besonders strenge forschungsethische Maßstäbe. Verwenden Sie die Bilder nur, wenn alle ethischen Aspekte berücksichtigt wurden. In diesem Zusammenhang sind auch Reverse Image Search Engines von Bedeutung, insbesondere wenn die zu zeigenden Bilder im Internet verfügbar sind. Trotz einer vermeintlichen Anonymisierung durch Verpixelung oder Verfremdung besteht die Möglichkeit, dass verschiedene Algorithmen und Technologien visuelle Merkmale wie Farben, Formen, Texturen und Muster erkennen. ",
        "noRecommendation": "Es gibt keine zusätzlichen ethischen Bedenken."
    },
    {
        "grouping": "Publikationskontexte",
        "short": "Repo?",
        "question": "Möchten Sie die personenbezogenen Bilder auf einem Online-Repositorium zur Verfügung stellen?",
        "answers": [
            "Ja",
            "Nein"
        ],
        "score": [
            2,
            0
        ],
        "info": "Im Wissenschaftskontext gibt es vielfältige Formen der Publikation und des Sichtbarmachens. Diese haben einen Einfluss auf forschungsethische Überlegungen beim Zeigen von personenbezogenen Bildern.",
        "yesRecommendation": "Stellen Sie vor dem Zeigen der Bilder sicher, dass der Kontext, in dem Sie die Bilder zeigen möchten, von der informierten Einwilligung abgedeckt ist. Gerade bei Open Science Praktiken und der Nutzung von Data Repositories ist der zukünftige Verwendungskontext (etwa die Fragestellung, mit der das visuelle Material untersucht werden könnte) nicht klar. Dies stellt Herausforderungen für die Vermittlung aller wichtigen Informationen im Zuge von Einwilligungsprozessen dar. Behandeln Sie personenbezogene visuelle Daten genauso streng wie personenbezogene textuelle Informationen (etwa Name, Geburtsdatum, Geschlecht, Alter, Wohnort). Verwenden Sie die Bilder nur, wenn alle ethischen Aspekte berücksichtigt wurden. In diesem Zusammenhang sind auch Reverse Image Search Engines von Bedeutung, insbesondere wenn die zu zeigenden Bilder im Internet verfügbar sind. Trotz einer vermeintlichen Anonymisierung durch Verpixelung oder Verfremdung besteht die Möglichkeit, dass verschiedene Algorithmen und Technologien visuelle Merkmale wie Farben, Formen, Texturen und Muster erkennen. Forschungsethische Empfehlungen für die Bereitstellung von personenbezogenen visuellen Daten, deren Aufbereitung und die Einschränkung des Zugriffs (etwa auf bestimmte Forschungsgruppen, nur nach Anfrage oder nur nach gewissen Fristen) sind aktuell noch nicht im Detail entwickelt. Bisher dominieren rechtliche Argumente die Entscheidungen bezüglich visueller Open-Data-Praktiken. Nach aktuellem Stand legen wir daher nahe, von der Bereitstellung von personenbezogenem Bildmaterial Abstand zu nehmen bzw. sehr strikte Anonymisierung aller personenbezogenen Informationen in einem Bild einzusetzen. In letzterem Fall stellt sich dann die Frage, ob die Bilder überhaupt noch für weitere Analysen brauchbar sind. ",
        "noRecommendation": "Es gibt keine zusätzlichen ethischen Bedenken."
    }
];